==> likwid-5.4.0.tar.gz: likwid-5.4.0/src/includes/perfmon_graviton3_counters.h <==
/*
 * =======================================================================================
 *
 *      Filename:  perfmon_graviton3_counters.h
 *
 *      Description:  Counter Header File of perfmon module for ARM AWS Graviton3
 *
 *      Version:   5.4.0
 *      Released:  15.11.2024
 *
 *      Author:   Carlos Falquez, c.falquez@fz-juelich.de
 *      Project:  likwid
 *
 *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
 *
 *      This program is free software: you can redistribute it and/or modify it under
 *      the terms of the GNU General Public License as published by the Free Software
 *      Foundation, either version 3 of the License, or (at your option) any later
 *      version.
 *
 *      This program is distributed in the hope that it will be useful, but WITHOUT ANY
 *      WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 *      PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License along with
 *      this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =======================================================================================
 */

#define NUM_COUNTERS_GRAVITON3 6

static RegisterMap graviton3_counter_map[NUM_COUNTERS_GRAVITON3] = {
    {"PMC0", PMC0, PMC, 0, 0, 0, 0, EVENT_OPTION_NONE_MASK},
    {"PMC1", PMC1, PMC, 0, 0, 0, 0, EVENT_OPTION_NONE_MASK},
    {"PMC2", PMC2, PMC, 0, 0, 0, 0, EVENT_OPTION_NONE_MASK},
    {"PMC3", PMC3, PMC, 0, 0, 0, 0, EVENT_OPTION_NONE_MASK},
    {"PMC4", PMC4, PMC, 0, 0, 0, 0, EVENT_OPTION_NONE_MASK},
    {"PMC5", PMC5, PMC, 0, 0, 0, 0, EVENT_OPTION_NONE_MASK},
};

static BoxMap graviton3_box_map[NUM_UNITS] = {
    [PMC] = {0, 0, 0, 0, 0, 0, 32},
};

static char* graviton3_translate_types[NUM_UNITS] = {
    [PMC] = "/sys/bus/event_source/devices/armv8_pmuv3_0",
};

==> likwid-5.5.0.tar.gz: likwid-5.5.0/src/includes/perfmon_graviton3_counters.h <==
/*
 * =======================================================================================
 *
 *      Filename:  perfmon_graviton3_counters.h
 *
 *      Description:  Counter Header File of perfmon module for ARM AWS Graviton3
 *
 *      Version:   <VERSION>
 *      Released:  <DATE>
 *
 *      Author:   Carlos Falquez, c.falquez@fz-juelich.de
 *      Project:  likwid
 *
 *      Copyright (C) 2022, Forschungszentrum Juelich, Germany
 *
 *      This program is free software: you can redistribute it and/or modify it under
 *      the terms of the GNU General Public License as published by the Free Software
 *      Foundation, either version 3 of the License, or (at your option) any later
 *      version.
 *
 *      This program is distributed in the hope that it will be useful, but WITHOUT ANY
 *      WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 *      PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License along with
 *      this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =======================================================================================
 */
#ifndef PERFMON_GRAVITON3_COUNTERS_H
#define PERFMON_GRAVITON3_COUNTERS_H

#define NUM_COUNTERS_GRAVITON3 6

static RegisterMap graviton3_counter_map[NUM_COUNTERS_GRAVITON3] = {
    {"PMC0", PMC0, PMC, 0, 0, 0, 0, EVENT_OPTION_NONE_MASK},
    {"PMC1", PMC1, PMC, 0, 0, 0, 0, EVENT_OPTION_NONE_MASK},
    {"PMC2", PMC2, PMC, 0, 0, 0, 0, EVENT_OPTION_NONE_MASK},
    {"PMC3", PMC3, PMC, 0, 0, 0, 0, EVENT_OPTION_NONE_MASK},
    {"PMC4", PMC4, PMC, 0, 0, 0, 0, EVENT_OPTION_NONE_MASK},
    {"PMC5", PMC5, PMC, 0, 0, 0, 0, EVENT_OPTION_NONE_MASK},
};

static BoxMap graviton3_box_map[NUM_UNITS] = {
    [PMC] = {0, 0, 0, 0, 0, 0, 32, 0, 0},
};

static char* graviton3_translate_types[NUM_UNITS] = {
    [PMC] = "/sys/bus/event_source/devices/armv8_pmuv3_0",
};

#endif //PERFMON_GRAVITON3_COUNTERS_H
